@@ -31,7 +31,7 @@
 
 #include "partclone.h"
 #include "reiser4clone.h"
-
+#include "progress.h"
 
 aal_device_t           *fs_device;
 reiser4_fs_t           *fs = NULL;
@@ -88,16 +88,23 @@ static void fs_close(){
 }
 
 /// readbitmap - read bitmap
-extern void readbitmap(char* device, image_head image_hdr, char*bitmap)
+extern void readbitmap(char* device, image_head image_hdr, char*bitmap, int pui)
 {
     reiser4_bitmap_t       *fs_bitmap;
     unsigned long long     bit, block, bused = 0, bfree = 0;
     int                    debug = 2;
+    int start = 0;
+    int bit_size = 1;
 
     fs_open(device);
     fs_bitmap = reiser4_bitmap_create(reiser4_format_get_len(fs->format));
     reiser4_alloc_extract(fs->alloc, fs_bitmap);
 
+    /// init progress
+    progress_bar   prog;	/// progress_bar structure defined in progress.h
+    progress_init(&prog, start, image_hdr.totalblock, bit_size);
+
+
     for(bit = 0; bit < reiser4_format_get_len(fs->format); bit++){
 	block = bit ;
 	if(reiser4_bitmap_test(fs_bitmap, bit)){
@@ -109,12 +116,17 @@ extern void readbitmap(char* device, image_head image_hdr, char*bitmap)
 	    bfree++;
 	    log_mesg(3, 0, 0, debug, "bitmap is free %lli", block);
 	}
+	/// update progress
+	update_pui(&prog, bit, 0);
+
     }
 
     if(bfree != reiser4_format_get_free(fs->format))
 	log_mesg(0, 1, 1, debug, "bitmap free count err, bfree:%lli, sfree=%lli\n", bfree, reiser4_format_get_free(fs->format));
 
     fs_close();
+    /// update progress
+    update_pui(&prog, bit, 1);
 }
 
 /// read super block and write to image head
